]> sigrok.org Git - libsigrok.git/blobdiff - strutil.c
sr: Remove unneeded temp. variable use.
[libsigrok.git] / strutil.c
index cd2ab449ec75967bcdc1fe4a72e83a6d3952125d..9a791e1950f7c05e7f029bb99d509866e6f23007 100644 (file)
--- a/strutil.c
+++ b/strutil.c
  * E.g. a value of 3000000 would be converted to "3 MHz", 20000 to "20 kHz".
  *
  * @param samplerate The samplerate in Hz.
* @return A malloc()ed string representation of the samplerate value,
*         or NULL upon errors. The caller is responsible to free() the memory.
  */
-char *sr_samplerate_string(uint64_t samplerate)
+SR_API char *sr_samplerate_string(uint64_t samplerate)
 {
        char *o;
        int r;
 
-       o = malloc(30 + 1); /* Enough for a uint64_t as string + " GHz". */
-       if (!o)
+       /* Allocate enough for a uint64_t as string + " GHz". */
+       if (!(o = g_try_malloc0(30 + 1))) {
+               sr_err("strutil: %s: o malloc failed", __func__);
                return NULL;
+       }
 
        if (samplerate >= SR_GHZ(1))
                r = snprintf(o, 30, "%" PRIu64 " GHz", samplerate / 1000000000);
@@ -53,7 +57,7 @@ char *sr_samplerate_string(uint64_t samplerate)
 
        if (r < 0) {
                /* Something went wrong... */
-               free(o);
+               g_free(o);
                return NULL;
        }
 
@@ -67,17 +71,21 @@ char *sr_samplerate_string(uint64_t samplerate)
  * E.g. a value of 3000000 would be converted to "3 us", 20000 to "50 ms".
  *
  * @param frequency The frequency in Hz.
* @return A malloc()ed string representation of the frequency value,
*         or NULL upon errors. The caller is responsible to free() the memory.
  */
-char *sr_period_string(uint64_t frequency)
+SR_API char *sr_period_string(uint64_t frequency)
 {
        char *o;
        int r;
 
-       o = malloc(30 + 1); /* Enough for a uint64_t as string + " ms". */
-       if (!o)
+       /* Allocate enough for a uint64_t as string + " ms". */
+       if (!(o = g_try_malloc0(30 + 1))) {
+               sr_err("strutil: %s: o malloc failed", __func__);
                return NULL;
+       }
 
        if (frequency >= SR_GHZ(1))
                r = snprintf(o, 30, "%" PRIu64 " ns", frequency / 1000000000);
@@ -90,7 +98,7 @@ char *sr_period_string(uint64_t frequency)
 
        if (r < 0) {
                /* Something went wrong... */
-               free(o);
+               g_free(o);
                return NULL;
        }
 
@@ -100,12 +108,13 @@ char *sr_period_string(uint64_t frequency)
 /**
  * TODO
  *
- * @param device TODO
+ * @param dev TODO
  * @param triggerstring TODO
+ *
  * @return TODO
  */
-char **sr_parse_triggerstring(struct sr_device *device,
-                             const char *triggerstring)
+SR_API char **sr_parse_triggerstring(struct sr_dev *dev,
+                                    const char *triggerstring)
 {
        GSList *l;
        struct sr_probe *probe;
@@ -113,7 +122,7 @@ char **sr_parse_triggerstring(struct sr_device *device,
        char **tokens, **triggerlist, *trigger, *tc, *trigger_types;
        gboolean error;
 
-       max_probes = g_slist_length(device->probes);
+       max_probes = g_slist_length(dev->probes);
        error = FALSE;
 
        if (!(triggerlist = g_try_malloc0(max_probes * sizeof(char *)))) {
@@ -122,7 +131,7 @@ char **sr_parse_triggerstring(struct sr_device *device,
        }
 
        tokens = g_strsplit(triggerstring, ",", max_probes);
-       trigger_types = device->plugin->get_device_info(0, SR_DI_TRIGGER_TYPES);
+       trigger_types = dev->plugin->dev_info_get(0, SR_DI_TRIGGER_TYPES);
        if (trigger_types == NULL)
                return NULL;
 
@@ -130,7 +139,7 @@ char **sr_parse_triggerstring(struct sr_device *device,
                if (tokens[i][0] < '0' || tokens[i][0] > '9') {
                        /* Named probe */
                        probenum = 0;
-                       for (l = device->probes; l; l = l->next) {
+                       for (l = dev->probes; l; l = l->next) {
                                probe = (struct sr_probe *)l->data;
                                if (probe->enabled
                                    && !strncmp(probe->name, tokens[i],
@@ -186,10 +195,10 @@ char **sr_parse_triggerstring(struct sr_device *device,
  *
  * @param sizestring A string containing a (decimal) size value.
  * @param size Pointer to uint64_t which will contain the string's size value.
- * @return SR_OK or error code
  *
+ * @return SR_OK upon success, SR_ERR upon errors.
  */
-int sr_parse_sizestring(const char *sizestring, uint64_t *size)
+SR_API int sr_parse_sizestring(const char *sizestring, uint64_t *size)
 {
        int multiplier, done;
        char *s;
@@ -247,7 +256,7 @@ int sr_parse_sizestring(const char *sizestring, uint64_t *size)
  * TODO: picoseconds?
  * TODO: Allow both lower-case and upper-case.
  */
-uint64_t sr_parse_timestring(const char *timestring)
+SR_API uint64_t sr_parse_timestring(const char *timestring)
 {
        uint64_t time_msec;
        char *s;
@@ -270,15 +279,15 @@ uint64_t sr_parse_timestring(const char *timestring)
        return time_msec;
 }
 
-gboolean sr_parse_boolstring(const char *boolstr)
+SR_API gboolean sr_parse_boolstring(const char *boolstr)
 {
        if (!boolstr)
                return FALSE;
 
-       if (!g_strcasecmp(boolstr, "true") || 
+       if (!g_strcasecmp(boolstr, "true") ||
            !g_strcasecmp(boolstr, "yes") ||
            !g_strcasecmp(boolstr, "on") ||
-           !g_strcasecmp(boolstr, "1")) 
+           !g_strcasecmp(boolstr, "1"))
                return TRUE;
 
        return FALSE;
@@
  *
  * @param samplerate The samplerate in Hz.
- * @return A malloc()ed string representation of the samplerate value,
- *         or NULL upon errors. The caller is responsible to free() the memory.
+ *
+ * @return A g_try_malloc()ed string representation of the samplerate value,
+ *         or NULL upon errors. The caller is responsible to g_free() the
+ *         memory.
  */
@@ -67,17 +71,21 @@ char *sr_samplerate_string(uint64_t samplerate)
  *
  * @param frequency The frequency in Hz.
- * @return A malloc()ed string representation of the frequency value,
- *         or NULL upon errors. The caller is responsible to free() the memory.
+ *
+ * @return A g_try_malloc()ed string representation of the frequency value,
+ *         or NULL upon errors. The caller is responsible to g_free() the
+ *         memory.
  */